@@ -1,6 +1,6 @@
 /* GNU/Linux/aarch64 specific target description, for the remote server
    for GDB.
-   Copyright (C) 2017 Free Software Foundation, Inc.
+   Copyright (C) 2017-2019 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -21,26 +21,37 @@
 #include "tdesc.h"
 #include "arch/aarch64.h"
 #include "linux-aarch32-low.h"
+#include <inttypes.h>
+
+/* All possible aarch64 target descriptors.  */
+struct target_desc *tdesc_aarch64_list[AARCH64_MAX_SVE_VQ + 1][2/*pauth*/];
 
 /* Create the aarch64 target description.  */
 
 const target_desc *
-aarch64_linux_read_description ()
+aarch64_linux_read_description (uint64_t vq, bool pauth_p)
 {
-  static target_desc *aarch64_tdesc = NULL;
-  target_desc **tdesc = &aarch64_tdesc;
+  if (vq > AARCH64_MAX_SVE_VQ)
+    error (_("VQ is %" PRIu64 ", maximum supported value is %d"), vq,
+	   AARCH64_MAX_SVE_VQ);
 
-  if (*tdesc == NULL)
+  struct target_desc *tdesc = tdesc_aarch64_list[vq][pauth_p];
+
+  if (tdesc == NULL)
     {
-      *tdesc = aarch64_create_target_description ();
+      tdesc = aarch64_create_target_description (vq, pauth_p);
 
-      init_target_desc (*tdesc);
-
-#ifndef IN_PROCESS_AGENT
       static const char *expedite_regs_aarch64[] = { "x29", "sp", "pc", NULL };
-      (*tdesc)->expedite_regs = expedite_regs_aarch64;
-#endif
+      static const char *expedite_regs_aarch64_sve[] = { "x29", "sp", "pc",
+							 "vg", NULL };
+
+      if (vq == 0)
+	init_target_desc (tdesc, expedite_regs_aarch64);
+      else
+	init_target_desc (tdesc, expedite_regs_aarch64_sve);
+
+      tdesc_aarch64_list[vq][pauth_p] = tdesc;
     }
 
-  return *tdesc;
+  return tdesc;
 }
